@@ -1,12 +1,3 @@
-/* DSTART                                                                    */
-/*                                                                           */
-/*           maildrop - mail delivery agent with filtering abilities         */
-/*                                                                           */
-/*  Copyright 1998-1999, Double Precision Inc.                               */
-/*                                                                           */
-/*  This program is distributed under the terms of the GNU General Public    */
-/*  License. See COPYING for additional information.                         */
-/* DEND                                                                      */
 
 #include	"message.h"
 #include	"messageinfo.h"
@@ -14,7 +5,7 @@
 #ifndef	maildrop_h
 #define	maildrop_h
 
-static const char maildrop_h_rcsid[]="$Id: maildrop.h 1.6 1999/09/10 02:10:05 mrsam Exp $";
+static const char maildrop_h_rcsid[]="$Id: maildrop.h,v 1.7 2006/10/02 00:03:37 mrsam Exp $";
 
 ////////////////////////////////////////////////////////////////////////////
 //
@@ -32,6 +23,7 @@ public:
 static	int sigfpe;		// Floating point exception trapped.
 	int includelevel;	// Catch include loops
 	int embedded_mode;	// Running in embedded mode
+	int authlib_essential;	// Whether authlib is essential
 
 	Message *msgptr, *savemsgptr;	// msgptr is the current message.
 					// savemsgptr points to a spare message
