@@ -1,7 +1,7 @@
 #ifndef recipenode_h
 #define	recipenode_h
 
-static const char recipenode_h_rcsid[]="$Id: recipenode.h,v 1.8 2000/07/01 22:36:34 mrsam Exp $";
+static const char recipenode_h_rcsid[]="$Id: recipenode.h,v 1.9 2004/01/15 03:12:13 mrsam Exp $";
 
 #include	"buffer.h"
 class Recipe;
@@ -116,7 +116,8 @@ public:
 		gdbmfetch,
 		gdbmstore,
 		timetoken,
-		importtoken
+		importtoken,
+		unset
 		} nodeType;
 
 	RecipeNode(RecipeNodeType);
